GraphQLStringMaxType class

Inheritance

Constructors

GraphQLStringMaxType(int max, {String? description, String name = 'String'})

Properties

description → String
A description of this type, which, while optional, can be very useful in tools like GraphiQL.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
max → int
final
name → String
The name of this type.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueType → Type
no setterinherited

Methods

coerceToInputObject() → GraphQLType<String, String>
Turns this type into one suitable for being provided as an input to a GraphQLObjectField.
inherited
convert(Object? value) → String?
Attempts to cast a dynamic value into a Serialized instance.
inherited
deserialize(String serialized) → String
Deserializes a serialized value.
inherited
list() → GraphQLListType<String, String>
inherited
nonNullable() → GraphQLType<String, String>
Creates a non-nullable type that represents this type, and enforces that a field of this type is present in input data.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(String value) → String
Serializes an arbitrary input value.
inherited
toString() → String
A string representation of this object.
inherited
validate(String key, covariant Object? input) → ValidationResult<String>
Performs type coercion against an input value, and returns a list of errors if the validation was unsuccessful.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited