GraphQLStringType class

Inheritance
Implementers

Constructors

GraphQLStringType({String name = 'String', String description = 'A character sequence.'})

Properties

description → String
A description of this type, which, while optional, can be very useful in tools like GraphiQL.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of this type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueType → Type
no setterinherited

Methods

coerceToInputObject() → GraphQLType<String, String>
Turns this type into one suitable for being provided as an input to a GraphQLObjectField.
override
convert(Object? value) → String?
Attempts to cast a dynamic value into a Serialized instance.
inherited
deserialize(String serialized) → String
Deserializes a serialized value.
override
list() → GraphQLListType<String, String>
inherited
nonNullable() → GraphQLType<String, String>
Creates a non-nullable type that represents this type, and enforces that a field of this type is present in input data.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(String value) → String
Serializes an arbitrary input value.
override
toString() → String
A string representation of this object.
inherited
validate(String key, covariant dynamic input) → ValidationResult<String>
Performs type coercion against an input value, and returns a list of errors if the validation was unsuccessful.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited